@@ -1,23 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2008 by Joris Guisson and Ivan Vasic                    *
- *   joris.guisson@gmail.com                                               *
- *   ivasic@gmail.com                                                      *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008 Joris Guisson <joris.guisson@gmail.com>
+    SPDX-FileCopyrightText: 2008 Ivan Vasic <ivasic@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include <QDomElement>
 #include <QFile>
@@ -155,15 +140,15 @@ void Feed::load(FilterList *filter_list)
     BDictNode *dict = (BDictNode *)n;
 
     try {
-        url = QUrl(dict->getString("url", 0));
-        cookie = dict->getValue("cookie") ? dict->getString("cookie", 0) : QString();
-        custom_name = dict->getValue("custom_name") ? dict->getString("custom_name", 0) : QString();
+        url = QUrl(dict->getString("url", nullptr));
+        cookie = dict->getValue("cookie") ? dict->getString("cookie", nullptr) : QString();
+        custom_name = dict->getValue("custom_name") ? dict->getString("custom_name", nullptr) : QString();
         refresh_rate = dict->getValue("refresh_rate") ? dict->getInt("refresh_rate") : DEFAULT_REFRESH_RATE;
 
         BListNode *fl = dict->getList("filters");
         if (fl) {
             for (Uint32 i = 0; i < fl->getNumChildren(); i++) {
-                Filter *f = filter_list->filterByID(fl->getString(i, 0));
+                Filter *f = filter_list->filterByID(fl->getString(i, nullptr));
                 if (f)
                     filters.append(f);
             }
@@ -172,7 +157,7 @@ void Feed::load(FilterList *filter_list)
         BListNode *ll = dict->getList("loaded");
         if (ll) {
             for (Uint32 i = 0; i < ll->getNumChildren(); i++) {
-                loaded.insert(ll->getString(i, 0));
+                loaded.insert(ll->getString(i, nullptr));
             }
         }
 
@@ -183,7 +168,7 @@ void Feed::load(FilterList *filter_list)
                 if (!se)
                     continue;
 
-                Filter *f = filter_list->filterByID(se_list->getString(i, 0));
+                Filter *f = filter_list->filterByID(se_list->getString(i, nullptr));
                 if (!f)
                     continue;
 
